@@ -18,19 +18,15 @@
 # include <config.h>
 #endif
 
-#ifdef HAVE_STRING_H
-# define _GNU_SOURCE    /* FIXME! */
-# include <string.h>
-#endif
-#ifdef HAVE_STDLIB_H
-# include <stdlib.h>
-#endif
+#define _GNU_SOURCE
+#include <sys/types.h>
+#include <string.h>
+#include <stdlib.h>
 #include <assert.h>
 #include <errno.h>
 #ifndef _WIN32
 # include <pwd.h>
 #endif
-#include <sys/types.h>
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
 #endif
@@ -41,6 +37,7 @@
 #define is_set(f, x) (((f) & (x)) == (f))
 
 #if defined(ENABLE_NLS) && defined(HAVE_GETTEXT)
+# include <locale.h>
 # include <libintl.h>
 # define _(str) dgettext(PACKAGE, str)
 #else
@@ -65,7 +62,6 @@ const char confuse_author[] = "Martin Hedenfalk <martin@bzero.se>";
 
 static int cfg_parse_internal(cfg_t *cfg, int level,
                               int force_state, cfg_opt_t *force_opt);
-static cfg_value_t *cfg_setopt(cfg_t *cfg, cfg_opt_t *opt, char *value);
 
 #define STATE_CONTINUE 0
 #define STATE_EOF -1
@@ -531,7 +527,8 @@ static void cfg_init_defaults(cfg_t *cfg)
     }
 }
 
-static cfg_value_t *cfg_setopt(cfg_t *cfg, cfg_opt_t *opt, char *value)
+DLLIMPORT cfg_value_t *
+cfg_setopt(cfg_t *cfg, cfg_opt_t *opt, char *value)
 {
     cfg_value_t *val = 0;
     int b;
@@ -571,7 +568,7 @@ static cfg_value_t *cfg_setopt(cfg_t *cfg, cfg_opt_t *opt, char *value)
 		 * non-NULL section title. */
                 assert(opt->nvalues == 0 || value);
 
-                for(i = 0; i < opt->nvalues; i++)
+                for(i = 0; i < opt->nvalues && val == NULL; i++)
                 {
                     cfg_t *sec = opt->values[i]->section;
                     if(is_set(CFGF_NOCASE, cfg->flags))
@@ -591,7 +588,7 @@ static cfg_value_t *cfg_setopt(cfg_t *cfg, cfg_opt_t *opt, char *value)
                     return 0;
                 }
             }
-            if(val == 0)
+            if(val == NULL)
                 val = cfg_addval(opt);
         }
         else
@@ -957,6 +954,7 @@ static int cfg_parse_internal(cfg_t *cfg, int level,
                     return STATE_ERROR;
 
                 val->section->line = cfg->line;
+		val->section->errfunc = cfg->errfunc;
                 rc = cfg_parse_internal(val->section, level+1,-1,0);
                 cfg->line = val->section->line;
                 if(rc != STATE_EOF)
@@ -1226,6 +1224,7 @@ DLLIMPORT void cfg_free(cfg_t *cfg)
 DLLIMPORT int cfg_include(cfg_t *cfg, cfg_opt_t *opt, int argc,
                           const char **argv)
 {
+    opt = NULL;
     if(argc != 1)
     {
         cfg_error(cfg, _("wrong number of arguments to cfg_include()"));
